table_1_triangle is the development triangle from the reference article
table_1_triangle.Rdtable_1_triangle is the development triangle from the reference article
"A Flexible Framework for Stochastic Reserving Models" found at https://variancejournal.org/article/120823